@@ -59,4 +59,10 @@ utils::globalVariables(c("%>%",
                          "scale_size",
                          "unit",
                          "cell.barcodes",
+                         "Expression",
+                         "Conditions",
+                         "col.legend.bin",
+                         "Clusters",
+                         "Rphenograph",
+                         "membership",
                          "yend"))
